PamConfig class

Constructors

PamConfig(String pamServer, String publicDBAlias, String loginDBAlias, String trackingConsentMessageID, bool enableLog, {required PamIdentityMatcher identityMatcher, bool blockEventsIfNoConsent = false, PamIdentityProvider? identityProvider, PamIdentityMismatchHandler? onIdentityMismatch})

Properties

blockEventsIfNoConsent bool
getter/setter pair
enableLog bool
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
identityMatcher PamIdentityMatcher
final
identityProvider PamIdentityProvider?
getter/setter pair
loginDBAlias String
getter/setter pair
onIdentityMismatch PamIdentityMismatchHandler?
getter/setter pair
pamServer String
getter/setter pair
publicDBAlias String
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
trackingConsentMessageID String
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited