PamUserState class
Constructors
- PamUserState.anonymous()
-
const
- PamUserState.identified(String value)
- PamUserState.unknown()
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- identity → PamUserIdentity?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → PamUserStateType
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited