PamIdentityMismatch class
Constructors
- PamIdentityMismatch({required PamIdentityMismatchType type, required PamUserIdentity? oldIdentity, required PamUserIdentity? newIdentity, required String event})
-
const
Properties
- event → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- newIdentity → PamUserIdentity?
-
final
- oldIdentity → PamUserIdentity?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → PamIdentityMismatchType
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited